SystemCursor

Enum SystemCursor 

pub enum SystemCursor {
    Default,
    Arrow,
    CrossHair,
    NotAllowed,
    IBeam,
    Hand,
    ResizeDown,
    ResizeLeft,
    ResizeRight,
    ResizeUp,
}
These cursor are guaranteed to be available on all platforms, or appropriate alternatives that carry the meaning of the cursor exist.

Notes:

  • On macOS, there is no way to set the wait (spinning) cursor.

Variants



Default

The platform-dependent default cursor (most likely the SystemCursor::Arrow).



Arrow

An arrow-like cursor, which is most likely the default cursor.



CrossHair

Used for indicating insertion points/high precision operations.



NotAllowed

Used for indicating that the action is not allowed, e.g. drag-and-drop, hover over a disabled element.



IBeam

The text selection cursor.



Hand

The (open) hand cursor, often used for clickable components, like links and buttons.



ResizeDown

Used for resizing the window or view from the bottom of the object.



ResizeLeft

Used for resizing the window or view from the left side of the object.



ResizeRight

Used for resizing the window or view from the right side of the object.



ResizeUp

Used for resizing the window or view from the top of the object.