pub enum SystemCursor {
Default,
Arrow,
CrossHair,
NotAllowed,
IBeam,
Hand,
ResizeDown,
ResizeLeft,
ResizeRight,
ResizeUp,
}Expand description
These cursor are guaranteed to be available on all platforms, or appropriate alternatives that carry the meaning of the cursor exist.
Notes:
- On macOS, there is no way to set the wait (spinning) cursor.
Variants
Default
The platform-dependent default cursor (most likely the
SystemCursor::Arrow).
Arrow
An arrow-like cursor, which is most likely the default cursor.
- macOS: arrowCursor
- Windows: IDC_ARROW
CrossHair
Used for indicating insertion points/high precision operations.
- macOS: crosshairCursor
- Windows: IDC_CROSS
NotAllowed
Used for indicating that the action is not allowed, e.g. drag-and-drop, hover over a disabled element.
- macOS: operationNotAllowedCursor
- Windows: IDC_NO
IBeam
The text selection cursor.
- macOS: IBeamCursor
- Windows: IDC_IBEAM
Hand
The (open) hand cursor, often used for clickable components, like links and buttons.
- macOS: pointingHandCursor
- Windows: IDC_HAND
ResizeDown
Used for resizing the window or view from the bottom of the object.
- macOS: resizeDownCursor
- Windows: IDC_SIZENS
ResizeLeft
Used for resizing the window or view from the left side of the object.
- macOS: resizeLeftCursor
- Windows: IDC_SIZEWE
ResizeRight
Used for resizing the window or view from the right side of the object.
- macOS: resizeRightCursor
- Windows: IDC_SIZEWE
ResizeUp
Used for resizing the window or view from the top of the object.
- macOS: resizeUpCursor
- Windows: IDC_SIZENS